Stan Math Library: stan::math::gevv_vvv_vari Class Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Static Protected Member Functions | Protected Attributes | List of all members
stan::math::gevv_vvv_vari Class Reference

`#include <gevv_vvv_vari.hpp>`

Inheritance diagram for stan::math::gevv_vvv_vari:

## Public Member Functions
| gevv_vvv_vari (const stan::math::var *alpha, const stan::math::var *v1, int stride1, const stan::math::var *v2, int stride2, size_t length)
virtual | ~gevv_vvv_vari ()
void | chain ()
| Apply the chain rule to this variable based on the variables on which it depends. More...
Public Member Functions inherited from stan::math::vari
| vari (const double x)
| Construct a variable implementation from a value. More...
| vari (const double x, bool stacked)
virtual | ~vari ()
| Throw an illegal argument exception. More...
void | init_dependent ()
| Initialize the adjoint for this (dependent) variable to 1. More...
void | set_zero_adjoint ()
| Set the adjoint value of this variable to 0. More...

## Static Protected Member Functions
static double | eval_gevv (const stan::math::var *alpha, const stan::math::var *v1, int stride1, const stan::math::var *v2, int stride2, size_t length, double *dotprod)

## Protected Attributes
stan::math::vari * | alpha_
stan::math::vari ** | v1_
stan::math::vari ** | v2_
double | dotval_
size_t | length_

## Additional Inherited Members
Static Public Member Functions inherited from stan::math::vari
static void * | operator new (size_t nbytes)
| Allocate memory from the underlying memory pool. More...
static void | operator delete (void *)
| Delete a pointer from the underlying memory pool. More...
Public Attributes inherited from stan::math::vari
const double | val_
| The value of this variable. More...
double | adj_
| The adjoint of this variable, which is the partial derivative of this variable with respect to the root variable. More...

## Detailed Description

Definition at line 11 of file gevv_vvv_vari.hpp.

## Constructor & Destructor Documentation

stan::math::gevv_vvv_vari::gevv_vvv_vari | ( | const stan::math::var * | alpha,
|  | const stan::math::var * | v1,
|  | int | stride1,
|  | const stan::math::var * | v2,
|  | int | stride2,
|  | size_t | length
| ) |  |
| inline

Definition at line 30 of file gevv_vvv_vari.hpp.

virtual stan::math::gevv_vvv_vari::~gevv_vvv_vari | ( |  | ) |
| inlinevirtual

Definition at line 46 of file gevv_vvv_vari.hpp.

## Member Function Documentation

void stan::math::gevv_vvv_vari::chain | ( |  | ) |
| inlinevirtual

Apply the chain rule to this variable based on the variables on which it depends.

The base implementation in this class is a no-op.

Reimplemented from stan::math::vari.

Definition at line 47 of file gevv_vvv_vari.hpp.

static double stan::math::gevv_vvv_vari::eval_gevv | ( | const stan::math::var * | alpha,
|  | const stan::math::var * | v1,
|  | int | stride1,
|  | const stan::math::var * | v2,
|  | int | stride2,
|  | size_t | length,
|  | double * | dotprod
| ) |  |
| inlinestaticprotected

Definition at line 18 of file gevv_vvv_vari.hpp.

## Member Data Documentation

stan::math::vari* stan::math::gevv_vvv_vari::alpha_
| protected

Definition at line 13 of file gevv_vvv_vari.hpp.

double stan::math::gevv_vvv_vari::dotval_
| protected

Definition at line 16 of file gevv_vvv_vari.hpp.

size_t stan::math::gevv_vvv_vari::length_
| protected

Definition at line 17 of file gevv_vvv_vari.hpp.

stan::math::vari** stan::math::gevv_vvv_vari::v1_
| protected

Definition at line 14 of file gevv_vvv_vari.hpp.

stan::math::vari** stan::math::gevv_vvv_vari::v2_
| protected

Definition at line 15 of file gevv_vvv_vari.hpp.

The documentation for this class was generated from the following file:

- stan/math/rev/core/gevv_vvv_vari.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.